/*****************************************************************************
*
* ALPS Project: Algorithms and Libraries for Physics Simulations
*
* ALPS Libraries
*
* Copyright (C) 1994-2010 by Matthias Troyer <troyer@itp.phys.ethz.ch>,
*                            Synge Todo <wistaria@comp-phys.org>
*
* This software is part of the ALPS libraries, published under the ALPS
* Library License; you can use, redistribute it and/or modify it under
* the terms of the license, either version 1 or (at your option) any later
* version.
* 
* You should have received a copy of the ALPS Library License along with
* the ALPS Libraries; see the file LICENSE.txt. If not, the license is also
* available from http://alps.comp-phys.org/.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
* FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT 
* SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE 
* FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE, 
* ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
* DEALINGS IN THE SOFTWARE.
*
*****************************************************************************/

#ifndef ALPS_CONFIG_H
#define ALPS_CONFIG_H

//
// use boost filesystem version 2 (nessesary from boost 1.46 upwards)
//
#define BOOST_FILESYSTEM_VERSION 3
#define BOOST_FILESYSTEM_DEPRECATED

//
// C headers
//

// Define to 1 if you have rpc/rpc.h and rpc/xdr.h
/* #undef ALPS_HAVE_RPC_XDR_H */

// Define to 1 if you have the <stdarg.h> header file.
#define ALPS_HAVE_STDARG_H

// Define to 1 if you have the <sys/stat.h> header file.
#define ALPS_HAVE_SYS_STAT_H

// Define to 1 if you have the <sys/systeminfo.h> header file.
/* #undef ALPS_HAVE_SYS_SYSTEMINFO_H */

// Define to 1 if you have the <sys/types.h> header file.
#define ALPS_HAVE_SYS_TYPES_H

// Define to 1 if you have the <unistd.h> header file.
/* #undef ALPS_HAVE_UNISTD_H */

// Define to 1 if you have the <windows.h> header file.
#define ALPS_HAVE_WINDOWS_H

// If defined, the new ngs alea will be used, instead of the old alea
/* #undef ALPS_NGS_USE_NEW_ALEA */

// If defined, the openmpi specific ulfm is used.
/* #undef ALPS_NGS_OPENMPI_ULFM */

//
// Libraries
//

// Define to 1 if you have the PTHREAD library
/* #undef ALPS_HAVE_PTHREAD */

// Define to 1 if you have the MPI library
/* #undef ALPS_HAVE_MPI */

// Define to 1 if you have the HDF5 library
#define ALPS_HAVE_HDF5

// Define to 1 if you have the HDF5 library with parallel(MPI) support
/* #undef ALPS_HAVE_HDF5_PARALLEL */

// Define to 1 if you have the Boost.MPI library
/* #undef ALPS_HAVE_BOOST_MPI */

// Define to 1 if you have the Boost.Signals library
/* #undef ALPS_HAVE_BOOST_SIGNALS */

// Define to 1 if you have the Boost.ThreadMPI library
/* #undef ALPS_HAVE_BOOST_THREAD */

// Define to 1 if you have wchar support in Boost.Regex and Boost.Serialization
/* #undef ALPS_HAVE_BOOST_WCHAR */

//
// BLAS and LAPACK
//

// Define if you have BLAS library
#define ALPS_HAVE_BLAS

// Define if you have LAPACK library
#define ALPS_HAVE_LAPACK

// Define if you have Intel Math Kernel Library
/* #undef ALPS_HAVE_MKL */

// Define if you have the Digital Extended Math Library
/* #undef ALPS_HAVE_DXML */

// Define if you have SGI SCSL Library
/* #undef ALPS_HAVE_SCSL */

// Define if you have Mac OS X vecLib framework
/* #undef ALPS_HAVE_VECLIB */

// Define if you have IBM ESSL Library
/* #undef ALPS_HAVE_ESSL */

// Define if you have ATLAS library
/* #undef ALPS_HAVE_ATLAS */

// Set 8-byte integers for Boost bindings if needed
/* #undef BIND_FORTRAN_INTEGER_8 */

//
// XML parser
//

// Define to 1 if you use Expat XML parser by James Clark.
/* #undef ALPS_HAVE_EXPAT_PARSER */

// Define to 1 if you use Xerces C++ XML parser by Apache Software Foundation.
/* #undef ALPS_HAVE_XERCES_PARSER */

//
// Python
//

// Define to 1 if you have Python on your system.
#define ALPS_HAVE_PYTHON

// Define to 1 if Boost Numpy (>=1.63) is available
#define ALPS_HAVE_BOOST_NUMPY

//
// OpenMP
//

// Define to 1 if OpenMP Worker is supported in ALPS/parpack scheduler
/* #undef ALPS_ENABLE_OPENMP_WORKER */

//
// Introduce [int,uint]*_t into alps namespace
//

#ifndef _USE_MATH_DEFINES // define const in math.h
# define _USE_MATH_DEFINES
#endif

#include <boost/cstdint.hpp>

namespace alps {

using boost::int8_t;
using boost::int_least8_t;
using boost::int_fast8_t;
using boost::uint8_t;
using boost::uint_least8_t;
using boost::uint_fast8_t;

using boost::int16_t;
using boost::int_least16_t;
using boost::int_fast16_t;
using boost::uint16_t;
using boost::uint_least16_t;
using boost::uint_fast16_t;

using boost::int32_t;
using boost::int_least32_t;
using boost::int_fast32_t;
using boost::uint32_t;
using boost::uint_least32_t;
using boost::uint_fast32_t;

#ifndef BOOST_NO_INT64_T

using boost::int64_t;
using boost::int_least64_t;
using boost::int_fast64_t;
using boost::uint64_t;
using boost::uint_least64_t;
using boost::uint_fast64_t;

#endif

} // end namespace alps

#include <boost/config.hpp>

#ifndef BOOST_NO_VOID_RETURNS
# define ALPS_DUMMY_VOID void
# define ALPS_RETURN_VOID
#else
# define ALPS_DUMMY_VOID bool
# define ALPS_RETURN_VOID return true;
#endif

//
// for Microsoft Visual C++
//

#if defined(BOOST_HAS_DECLSPEC)
# if defined(ALPS_EXPORTS)
#  define ALPS_DECL __declspec(dllexport)
#  define ALPS_TEMPL_DECL __declspec(dllexport)
# else
#  define ALPS_DECL __declspec(dllimport)
#  define ALPS_TEMPL_DECL
# endif
# if defined(PYALPS_EXPORTS)
#  define PYALPS_DECL __declspec(dllexport)
#  define PYALPS_TEMPL_DECL __declspec(dllexport)
# else
#  define PYALPS_DECL __declspec(dllimport)
#  define PYALPS_TEMPL_DECL
# endif
#else
# define ALPS_TEMPL_DECL
# define ALPS_DECL
# define PYALPS_TEMPL_DECL
# define PYALPS_DECL
#endif

//
// Enable HDF5 checkpoints: no ALPS checkpoint data is written into XDR files 
// anymore, but they can still be read
//
#ifdef ALPS_HAVE_HDF5
#  define ALPS_ONLY_HDF5
#endif


#ifdef BOOST_MSVC
#define BOOST_NUMERIC_BINDINGS_USE_COMPLEX_STRUCT
#endif

#include <boost/numeric/bindings/detail/config/fortran.hpp>

#endif // ALPS_CONFIG_H
